@@ -15,8 +15,6 @@ lazy rules => sub {
   +{ map +($_ => [ undef ]), keys %{ $_[0]->base_rule_names } }
 };
 
-# global cache of compiled grammar regexps
-my %COMPILE_CACHE;
 lazy grammar_regexp => sub {
   my ($self) = @_;
   my @parts;
@@ -33,15 +31,8 @@ lazy grammar_regexp => sub {
   my $base_re = $self->base_grammar_regexp;
   return $base_re unless @parts;
   my $define_block = join "\n", '(?(DEFINE)', '', @parts, '', ')';
-  # This stringify is required for Perl v5.18 - v5.28
-  # (RT #126285, RT #144248).
-  my $final_re = "${define_block} ${base_re}";
-  return $COMPILE_CACHE{$final_re} ||= do {
-    use re 'eval';
-    my $re = qr{$final_re}x;
-    no re 'eval';
-    $re;
-  }
+  use re 'eval';
+  return qr{${define_block} ${base_re}}x;
 };
 
 sub _rule_name {
